/*
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


/*
 *    PreferenceStructurePanel.java
 *    Copyright (C) 2008 Jens Christian Hhn
 *
 *    (based upon)  BoundaryPanel.java
 *    Copyright (C) 2002 University of Waikato, Hamilton, New Zealand
 *
 */

package weka.classifiers;

import weka.core.Instance;

/**
 * PreferenceStructureHandler. An interface that signalizes that a classifier
 * is capable of returning a fuzzy preference structure with strict
 * preferences, conflicts and ignorance.
 * 
 * Date created: 08/07/2008
 * @author Jens Christian Hhn (huehn@gmx.net)
 * @version $Revision: 1.0 $
 */
public interface PreferenceStructureHandler {

  /**
   * A function that returns the strict preference,
   * conflict and ignorance relation for an instance.
   * @param inst Some instance for which the relations shall be calculated.
   * @return The preference structure
   * @throws Exception
   */
  public double[][][] relationsForInstance(Instance inst) throws Exception;
}
